editeng/source/editeng/impedit4.cxx            |    2 +-
 editeng/source/items/legacyitem.cxx            |    2 +-
 include/unotools/fontdefs.hxx                  |    8 ++++----
 oox/source/export/drawingml.cxx                |    2 +-
 sd/source/filter/eppt/pptx-text.cxx            |    2 +-
 svtools/source/misc/sampletext.cxx             |    4 ++--
 sw/source/core/txtnode/fntcache.cxx            |    2 +-
 sw/source/filter/ww8/writerwordglue.cxx        |    2 +-
 sw/source/filter/ww8/wrtw8num.cxx              |    2 +-
 unotools/source/misc/fontcvt.cxx               |    2 +-
 unotools/source/misc/fontdefs.cxx              |    2 +-
 vcl/qt5/QtFontFace.cxx                         |    4 ++--
 vcl/source/filter/wmf/wmfwr.cxx                |    2 +-
 vcl/source/font/PhysicalFontFace.cxx           |    4 ++--
 vcl/source/gdi/metaact.cxx                     |    4 ++--
 vcl/unx/generic/fontmanager/fontsubst.cxx      |    8 ++++----
 vcl/unx/generic/glyphs/freetype_glyphcache.cxx |    4 ++--
 vcl/win/gdi/salfont.cxx                        |    2 +-
 writerfilter/source/dmapper/FontTable.cxx      |    4 ++--
 19 files changed, 31 insertions(+), 31 deletions(-)

New commits:
commit 003c837e9d029a671ea95f76da45573bbc260eea
Author:     Caolán McNamara <caol...@redhat.com>
AuthorDate: Fri Nov 18 11:34:13 2022 +0000
Commit:     Caolán McNamara <caol...@redhat.com>
CommitDate: Fri Nov 18 14:55:12 2022 +0100

    rename IsStarSymbol to IsOpenSymbol
    
    Change-Id: If525ba9826f5bc2d860233cbabf58d1d290be054
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/142936
    Tested-by: Jenkins
    Reviewed-by: Caolán McNamara <caol...@redhat.com>

diff --git a/editeng/source/editeng/impedit4.cxx 
b/editeng/source/editeng/impedit4.cxx
index 85b771bc5a29..9f2b617428fa 100644
--- a/editeng/source/editeng/impedit4.cxx
+++ b/editeng/source/editeng/impedit4.cxx
@@ -362,7 +362,7 @@ ErrCode ImpEditEngine::WriteRTF( SvStream& rOutput, 
EditSelection aSel )
         // of RTL_TEXTENCODING_MS_1252 and pay no attention
         // on export what encoding we claim to use for these
         // fonts.
-        if (IsStarSymbol(pFontItem->GetFamilyName()))
+        if (IsOpenSymbol(pFontItem->GetFamilyName()))
             eChrSet = RTL_TEXTENCODING_UTF8;
         DBG_ASSERT( eChrSet != 9, "SystemCharSet?!" );
         if( RTL_TEXTENCODING_DONTKNOW == eChrSet )
diff --git a/editeng/source/items/legacyitem.cxx 
b/editeng/source/items/legacyitem.cxx
index 786b86c917ab..96742f46fcae 100644
--- a/editeng/source/items/legacyitem.cxx
+++ b/editeng/source/items/legacyitem.cxx
@@ -107,7 +107,7 @@ namespace legacy
 
         SvStream& Store(const SvxFontItem& rItem, SvStream& rStrm, sal_uInt16)
         {
-            const bool bToBats(IsStarSymbol(rItem.GetFamilyName()));
+            const bool bToBats(IsOpenSymbol(rItem.GetFamilyName()));
 
             
rStrm.WriteUChar(rItem.GetFamily()).WriteUChar(rItem.GetPitch()).WriteUChar(bToBats
 ?
                     RTL_TEXTENCODING_SYMBOL :
diff --git a/include/unotools/fontdefs.hxx b/include/unotools/fontdefs.hxx
index aff10c860122..ef03e8887a4b 100644
--- a/include/unotools/fontdefs.hxx
+++ b/include/unotools/fontdefs.hxx
@@ -96,15 +96,15 @@ UNOTOOLS_DLLPUBLIC OUString GetEnglishSearchFontName( 
std::u16string_view rName
 */
 UNOTOOLS_DLLPUBLIC OUString StripScriptFromName(const OUString& rName);
 
-/** Determine if the font is the special Star|Open Symbol font
+/** Determine if the font is the special Open|Star Symbol font
 
     @param rFontName
-    The FontName to test for being Star|Open Symbol
+    The FontName to test for being Open|Star Symbol
 
-    @return true if this is Star|Open Symbol
+    @return true if this is Open|Star Symbol
 */
 // FIXME It's quite possible that code using this should instead check for 
RTL_TEXTENCODING_SYMBOL.
-UNOTOOLS_DLLPUBLIC bool IsStarSymbol(std::u16string_view rFontName);
+UNOTOOLS_DLLPUBLIC bool IsOpenSymbol(std::u16string_view rFontName);
 
 #endif // INCLUDED_UNOTOOLS_FONTDEFS_HXX
 
diff --git a/oox/source/export/drawingml.cxx b/oox/source/export/drawingml.cxx
index 7c996be1d892..f7bf0ffdb6fe 100644
--- a/oox/source/export/drawingml.cxx
+++ b/oox/source/export/drawingml.cxx
@@ -4892,7 +4892,7 @@ void DrawingML::WriteConnectorConnections( sal_Int32 
nStartGlueId, sal_Int32 nEn
 
 sal_Unicode DrawingML::SubstituteBullet( sal_Unicode cBulletId, 
css::awt::FontDescriptor& rFontDesc )
 {
-    if ( IsStarSymbol(rFontDesc.Name) )
+    if ( IsOpenSymbol(rFontDesc.Name) )
     {
         rtl_TextEncoding eCharSet = rFontDesc.CharSet;
         cBulletId = msfilter::util::bestFitOpenSymbolToMSFont(cBulletId, 
eCharSet, rFontDesc.Name);
diff --git a/sd/source/filter/eppt/pptx-text.cxx 
b/sd/source/filter/eppt/pptx-text.cxx
index 85c37f77d729..d42d80590984 100644
--- a/sd/source/filter/eppt/pptx-text.cxx
+++ b/sd/source/filter/eppt/pptx-text.cxx
@@ -890,7 +890,7 @@ void ParagraphObj::ImplGetNumberingLevel( 
PPTExBulletProvider* pBuProv, sal_Int1
 
                     case SVX_NUM_CHAR_SPECIAL :                           // 
Bullet
                     {
-                        if ( IsStarSymbol(aFontDesc.Name) )
+                        if ( IsOpenSymbol(aFontDesc.Name) )
                         {
                             rtl_TextEncoding eChrSet = aFontDesc.CharSet;
                             cBulletId = 
msfilter::util::bestFitOpenSymbolToMSFont(cBulletId, eChrSet, aFontDesc.Name);
diff --git a/svtools/source/misc/sampletext.cxx 
b/svtools/source/misc/sampletext.cxx
index c59f5a7a43ec..a181fdde238c 100644
--- a/svtools/source/misc/sampletext.cxx
+++ b/svtools/source/misc/sampletext.cxx
@@ -137,7 +137,7 @@ bool isSymbolFont(const vcl::Font &rFont)
             rFont.GetFamilyName().startsWith("STIXNonUnicode") ||
             rFont.GetFamilyName().startsWith("STIXSize") ||
             rFont.GetFamilyName().startsWith("STIXVariants") ||
-            IsStarSymbol(rFont.GetFamilyName());
+            IsOpenSymbol(rFont.GetFamilyName());
 }
 
 bool canRenderNameOfSelectedFont(OutputDevice const &rDevice)
@@ -162,7 +162,7 @@ OUString 
makeShortRepresentativeSymbolTextForSelectedFont(OutputDevice const &rD
         return aImplAdobeSymbolText;
     }
 
-    const bool bOpenSymbol = IsStarSymbol(rDevice.GetFont().GetFamilyName());
+    const bool bOpenSymbol = IsOpenSymbol(rDevice.GetFont().GetFamilyName());
 
     if (!bOpenSymbol)
     {
diff --git a/sw/source/core/txtnode/fntcache.cxx 
b/sw/source/core/txtnode/fntcache.cxx
index 290ff8cc1276..5b26029b36dd 100644
--- a/sw/source/core/txtnode/fntcache.cxx
+++ b/sw/source/core/txtnode/fntcache.cxx
@@ -364,7 +364,7 @@ sal_uInt16 SwFntObj::GetFontLeading( const SwViewShell 
*pSh, const OutputDevice&
                Interestingly enough, bSymbol is false for 'StarSymbol; Arial 
Unicode MS', so
                also check explicitly.
             */
-            if( m_bSymbol || IsStarSymbol( m_pPrtFont->GetFamilyName()))
+            if( m_bSymbol || IsOpenSymbol( m_pPrtFont->GetFamilyName()))
                 m_nExtLeading = 0;
         }
 
diff --git a/sw/source/filter/ww8/writerwordglue.cxx 
b/sw/source/filter/ww8/writerwordglue.cxx
index f457905ffd9d..aa552fe3e78a 100644
--- a/sw/source/filter/ww8/writerwordglue.cxx
+++ b/sw/source/filter/ww8/writerwordglue.cxx
@@ -328,7 +328,7 @@ namespace myImplHelpers
 
     static OUString FindBestMSSubstituteFont(std::u16string_view rFont)
     {
-        if (IsStarSymbol(rFont))
+        if (IsOpenSymbol(rFont))
             return "Arial Unicode MS";
         return GetSubsFontName(rFont, SubsFontFlags::ONLYONE | 
SubsFontFlags::MS);
     }
diff --git a/sw/source/filter/ww8/wrtw8num.cxx 
b/sw/source/filter/ww8/wrtw8num.cxx
index 75f240fb3b83..29e93c1b956c 100644
--- a/sw/source/filter/ww8/wrtw8num.cxx
+++ b/sw/source/filter/ww8/wrtw8num.cxx
@@ -508,7 +508,7 @@ void MSWordExportBase::NumberingLevel(
         sFontName = pBulletFont->GetFamilyName();
         eFamily = pBulletFont->GetFamilyType();
 
-        if (IsStarSymbol(sFontName))
+        if (IsOpenSymbol(sFontName))
             SubstituteBullet(sNumStr, eChrSet, sFontName);
     }
 
diff --git a/unotools/source/misc/fontcvt.cxx b/unotools/source/misc/fontcvt.cxx
index 2c415dae969f..5abda6fdf9b2 100644
--- a/unotools/source/misc/fontcvt.cxx
+++ b/unotools/source/misc/fontcvt.cxx
@@ -1259,7 +1259,7 @@ sal_Unicode ConvertChar::RecodeChar( sal_Unicode cChar ) 
const
 
             if (!cRetVal && mpSubsFontName)
             {
-                if ( IsStarSymbol( OUString::createFromAscii(mpSubsFontName) ) 
)
+                if ( IsOpenSymbol( OUString::createFromAscii(mpSubsFontName) ) 
)
                 {
                     cRetVal = 0xE12C;
                     SAL_WARN( "unotools.misc", "Forcing a bullet substitution 
from 0x" <<
diff --git a/unotools/source/misc/fontdefs.cxx 
b/unotools/source/misc/fontdefs.cxx
index 49f0d09c65cb..3ec1226a289d 100644
--- a/unotools/source/misc/fontdefs.cxx
+++ b/unotools/source/misc/fontdefs.cxx
@@ -569,7 +569,7 @@ OUString GetSubsFontName( std::u16string_view rName, 
SubsFontFlags nFlags )
     return aName;
 }
 
-bool IsStarSymbol(std::u16string_view rFontName)
+bool IsOpenSymbol(std::u16string_view rFontName)
 {
     sal_Int32 nIndex = 0;
     OUString sFamilyNm(GetNextFontToken(rFontName, nIndex));
diff --git a/vcl/qt5/QtFontFace.cxx b/vcl/qt5/QtFontFace.cxx
index 9fd2eb56b2fb..d45fadafe87e 100644
--- a/vcl/qt5/QtFontFace.cxx
+++ b/vcl/qt5/QtFontFace.cxx
@@ -108,7 +108,7 @@ void QtFontFace::fillAttributesFromQFont(const QFont& 
rFont, FontAttributes& rFA
     QFontInfo aFontInfo(rFont);
 
     rFA.SetFamilyName(toOUString(aFontInfo.family()));
-    if (IsStarSymbol(toOUString(aFontInfo.family())))
+    if (IsOpenSymbol(toOUString(aFontInfo.family())))
         rFA.SetSymbolFlag(true);
     rFA.SetStyleName(toOUString(aFontInfo.styleName()));
     rFA.SetPitch(aFontInfo.fixedPitch() ? PITCH_FIXED : PITCH_VARIABLE);
@@ -142,7 +142,7 @@ QtFontFace* QtFontFace::fromQFontDatabase(const QString& 
aFamily, const QString&
     FontAttributes aFA;
 
     aFA.SetFamilyName(toOUString(aFamily));
-    if (IsStarSymbol(aFA.GetFamilyName()))
+    if (IsOpenSymbol(aFA.GetFamilyName()))
         aFA.SetSymbolFlag(true);
     aFA.SetStyleName(toOUString(aStyle));
     aFA.SetPitch(isFixedPitch ? PITCH_FIXED : PITCH_VARIABLE);
diff --git a/vcl/source/filter/wmf/wmfwr.cxx b/vcl/source/filter/wmf/wmfwr.cxx
index 2c287c8b693f..7c209b3a02ee 100644
--- a/vcl/source/filter/wmf/wmfwr.cxx
+++ b/vcl/source/filter/wmf/wmfwr.cxx
@@ -497,7 +497,7 @@ bool WMFWriter::WMFRecord_Escape_Unicode( const Point& 
rPoint, const OUString& r
                 }
             }
 
-            if ( ( i != nStringLen ) || IsStarSymbol( aSrcFont.GetFamilyName() 
) )    // after conversion the characters are not original, so we
+            if ( ( i != nStringLen ) || IsOpenSymbol( aSrcFont.GetFamilyName() 
) )    // after conversion the characters are not original, so we
             {                                                                  
 // will store the unicode string and a polypoly replacement
                 Color aOldFillColor( aSrcFillColor );
                 Color aOldLineColor( aSrcLineColor );
diff --git a/vcl/source/gdi/metaact.cxx b/vcl/source/gdi/metaact.cxx
index 035ba8cd45e5..cc92677c72b7 100644
--- a/vcl/source/gdi/metaact.cxx
+++ b/vcl/source/gdi/metaact.cxx
@@ -1679,11 +1679,11 @@ MetaFontAction::MetaFontAction( vcl::Font aFont ) :
     MetaAction  ( MetaActionType::FONT ),
     maFont      (std::move( aFont ))
 {
-    // #96876: because RTL_TEXTENCODING_SYMBOL is often set at the StarSymbol 
font,
+    // #96876: because RTL_TEXTENCODING_SYMBOL is often set at the OpenSymbol 
font,
     // we change the textencoding to RTL_TEXTENCODING_UNICODE here, which seems
     // to be the right way; changing the textencoding at other sources
     // is too dangerous at the moment
-    if ( IsStarSymbol( maFont.GetFamilyName() )
+    if ( IsOpenSymbol( maFont.GetFamilyName() )
         && ( maFont.GetCharSet() != RTL_TEXTENCODING_UNICODE ) )
     {
         maFont.SetCharSet( RTL_TEXTENCODING_UNICODE );
diff --git a/vcl/win/gdi/salfont.cxx b/vcl/win/gdi/salfont.cxx
index e2305d3f49ee..c41d0427f5cb 100644
--- a/vcl/win/gdi/salfont.cxx
+++ b/vcl/win/gdi/salfont.cxx
@@ -162,7 +162,7 @@ const std::map<OUString, OUString> aBitmapFontSubs =
 // TODO: See if Windows have API that we can use here to improve font fallback.
 bool 
WinPreMatchFontSubstititution::FindFontSubstitute(vcl::font::FontSelectPattern& 
rFontSelData) const
 {
-    if (rFontSelData.IsSymbolFont() || IsStarSymbol(rFontSelData.maSearchName))
+    if (rFontSelData.IsSymbolFont() || IsOpenSymbol(rFontSelData.maSearchName))
         return false;
 
     for (const auto& aSub : aBitmapFontSubs)
diff --git a/writerfilter/source/dmapper/FontTable.cxx 
b/writerfilter/source/dmapper/FontTable.cxx
index f0d4e7077742..ca12ac67b2c3 100644
--- a/writerfilter/source/dmapper/FontTable.cxx
+++ b/writerfilter/source/dmapper/FontTable.cxx
@@ -79,7 +79,7 @@ void FontTable::lcl_attribute(Id Name, Value & val)
             if( m_pImpl->pCurrentEntry->nTextEncoding == 
RTL_TEXTENCODING_DONTKNOW )
             {
                 m_pImpl->pCurrentEntry->nTextEncoding = 
rtl_getTextEncodingFromWindowsCharset( nIntValue );
-                if( IsStarSymbol( m_pImpl->pCurrentEntry->sFontName ))
+                if( IsOpenSymbol( m_pImpl->pCurrentEntry->sFontName ))
                     m_pImpl->pCurrentEntry->nTextEncoding = 
RTL_TEXTENCODING_SYMBOL;
             }
             break;
@@ -89,7 +89,7 @@ void FontTable::lcl_attribute(Id Name, Value & val)
             sValue.convertToString( &tmp, RTL_TEXTENCODING_ASCII_US, 
OUSTRING_TO_OSTRING_CVTFLAGS );
             m_pImpl->pCurrentEntry->nTextEncoding = 
rtl_getTextEncodingFromMimeCharset( tmp.getStr() );
             // Older LO versions used to write incorrect character set for 
OpenSymbol, fix.
-            if( IsStarSymbol( m_pImpl->pCurrentEntry->sFontName ))
+            if( IsOpenSymbol( m_pImpl->pCurrentEntry->sFontName ))
                 m_pImpl->pCurrentEntry->nTextEncoding = 
RTL_TEXTENCODING_SYMBOL;
             break;
         }

Reply via email to
diff --git a/vcl/source/font/PhysicalFontFace.cxx 
b/vcl/source/font/PhysicalFontFace.cxx
index 975ace9ad264..81f63d221013 100644
--- a/vcl/source/font/PhysicalFontFace.cxx
+++ b/vcl/source/font/PhysicalFontFace.cxx
@@ -46,9 +46,9 @@ PhysicalFontFace::PhysicalFontFace(const FontAttributes& rDFA)
     , mpHbUnscaledFont(nullptr)
     , mbFontCapabilitiesRead(false)
 {
     // StarSymbol is a unicode font, but it still deserves the symbol flag
     if (!IsSymbolFont())
-        if (IsStarSymbol(GetFamilyName()))
+        if (IsOpenSymbol(GetFamilyName()))
             SetSymbolFlag(true);
 }
 
@@ -46,9 +46,9 @@ PhysicalFontFace::PhysicalFontFace(const FontAttributes& rDFA)
     , mbFontCapabilitiesRead(false)
 {
-    // StarSymbol is a unicode font, but it still deserves the symbol flag
+    // OpenSymbol is a unicode font, but it still deserves the symbol flag
     if (!IsSymbolFont())
diff --git a/vcl/unx/generic/fontmanager/fontsubst.cxx 
b/vcl/unx/generic/fontmanager/fontsubst.cxx
index afbe53dd4a81..0f429723b21e 100644
--- a/vcl/unx/generic/fontmanager/fontsubst.cxx
+++ b/vcl/unx/generic/fontmanager/fontsubst.cxx
@@ -101,8 +101,8 @@ bool 
FcPreMatchSubstitution::FindFontSubstitute(vcl::font::FontSelectPattern &rF
     // We don't actually want to talk to Fontconfig at all for symbol fonts
     if( rFontSelData.IsSymbolFont() )
         return false;
-    // StarSymbol is a unicode font, but it still deserves the symbol flag
-    if ( IsStarSymbol(rFontSelData.maSearchName) )
+    // OpenSymbol is a unicode font, but it still deserves to be treated as a 
symbol font
+    if ( IsOpenSymbol(rFontSelData.maSearchName) )
         return false;
 
     //see fdo#41556 and fdo#47636
@@ -177,8 +177,8 @@ bool 
FcGlyphFallbackSubstitution::FindFontSubstitute(vcl::font::FontSelectPatter
     // We don't actually want to talk to Fontconfig at all for symbol fonts
     if( rFontSelData.IsSymbolFont() )
         return false;
-    // StarSymbol is a unicode font, but it still deserves the symbol flag
-    if ( IsStarSymbol(rFontSelData.maSearchName) )
+    // OpenSymbol is a unicode font, but it still deserves to be treated as a 
symbol font
+    if ( IsOpenSymbol(rFontSelData.maSearchName) )
         return false;
 
     const vcl::font::FontSelectPattern aOut = GetFcSubstitute( rFontSelData, 
rMissingCodes );
diff --git a/vcl/unx/generic/glyphs/freetype_glyphcache.cxx 
b/vcl/unx/generic/glyphs/freetype_glyphcache.cxx
index 460142a66ae8..d0f9e2588c5e 100644
--- a/vcl/unx/generic/glyphs/freetype_glyphcache.cxx
+++ b/vcl/unx/generic/glyphs/freetype_glyphcache.cxx
@@ -520,8 +520,8 @@ void FreetypeFont::GetFontMetric(ImplFontMetricDataRef 
const & rxTo) const
 
     rxTo->SetOrientation(mrFontInstance.GetFontSelectPattern().mnOrientation);
 
-    //Always consider [star]symbol as symbol fonts
-    if ( IsStarSymbol( rxTo->GetFamilyName() ) )
+    //Always consider [open]symbol as symbol fonts
+    if ( IsOpenSymbol( rxTo->GetFamilyName() ) )
         rxTo->SetSymbolFlag( true );
 
     FT_Activate_Size( maSizeFT );